TerminalManager

Struct TerminalManager 

pub struct TerminalManager { /* private fields */ }
Manages terminal processes spawned on Windows.

Implementations

Source

impl TerminalManager

pub fn new() -> Self

Create a new TerminalManager, auto-detecting the best available shell.

pub fn create_terminal(&mut self, command: &str) -> Result<TerminalId>

Create a terminal and start running a command.

pub fn get_output(&mut self, id: &TerminalId) -> Result<String>

Get new output from a terminal since the last call.

pub async fn wait_for_exit(&mut self, id: &TerminalId) -> Result<i32>

Wait for a terminal to exit and return its exit code.

pub fn release(&mut self, id: &TerminalId) -> Result<()>

Release (remove) a terminal.

pub async fn kill(&mut self, id: &TerminalId) -> Result<()>

Kill a terminal process.