pub struct TerminalManager { /* private fields */ }Expand description
Manages terminal processes spawned on Windows.
Implementations
Sourceimpl TerminalManager
impl TerminalManager
Sourcepub fn create_terminal(&mut self, command: &str) -> Result<TerminalId>
pub fn create_terminal(&mut self, command: &str) -> Result<TerminalId>
Create a terminal and start running a command.
Sourcepub fn get_output(&mut self, id: &TerminalId) -> Result<String>
pub fn get_output(&mut self, id: &TerminalId) -> Result<String>
Get new output from a terminal since the last call.
Sourcepub async fn wait_for_exit(&mut self, id: &TerminalId) -> Result<i32>
pub async fn wait_for_exit(&mut self, id: &TerminalId) -> Result<i32>
Wait for a terminal to exit and return its exit code.
Sourcepub fn release(&mut self, id: &TerminalId) -> Result<()>
pub fn release(&mut self, id: &TerminalId) -> Result<()>
Release (remove) a terminal.
Sourcepub async fn kill(&mut self, id: &TerminalId) -> Result<()>
pub async fn kill(&mut self, id: &TerminalId) -> Result<()>
Kill a terminal process.